@@ -1,7 +1,10 @@
-#line 1 "inc/Module/Install/Scripts.pm - /home/rking/local/share/perl/5.8.4/Module/Install/Scripts.pm"
+#line 1 "inc/Module/Install/Scripts.pm - /usr/share/perl5/Module/Install/Scripts.pm"
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Scripts.pm $ $Author: autrijus $
+# $Revision: #7 $ $Change: 1841 $ $DateTime: 2003/12/28 19:43:56 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Scripts;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.02';
+$VERSION = '0.01';
 use strict;
 use File::Basename ();
 
@@ -26,10 +29,10 @@ sub prompt_script {
 }
 
 sub install_script {
-    my $self = shift;
+    my ($self, $script_file) = @_;
     my $args = $self->makemaker_args;
     my $exe_files = $args->{EXE_FILES} ||= [];
-    push @$exe_files, @_;
+    push @$exe_files, $script_file;
 }
 
 sub _read_script {
